# ByteBird

Simple "Flappy Bird" like game for 7 segment display from ZeroSeg module for Raspberry Pi.

## Installation
```
$ pip3 install --user 7seg-ByteBird
```
## Usage
```
$ python3 -m ByteBird <time_delay*>
```
or simply
```
$ bytebird <time_delay*>
```
\* Optional: Time delay between updates - difficulty level, less = harder.
